@@ -1,6 +1,6 @@
 !-----------------------------------------------------------------------------!
 !   CP2K: A general program to perform molecular dynamics simulations         !
-!   Copyright (C) 2000 - 2017  CP2K developers group                          !
+!   Copyright (C) 2000 - 2018  CP2K developers group                          !
 !-----------------------------------------------------------------------------!
 
 ! *****************************************************************************
@@ -25,7 +25,7 @@ CONTAINS
 
 ! *****************************************************************************
 !> \brief Can be used to get a nice core
-! *****************************************************************************
+! **************************************************************************************************
   SUBROUTINE m_abort()
     INTERFACE
       SUBROUTINE abort() BIND(C,name="abort")
@@ -38,7 +38,8 @@ CONTAINS
 
 ! *****************************************************************************
 !> \brief The number of arguments of the fortran program
-! *****************************************************************************
+!> \return ...
+! **************************************************************************************************
   FUNCTION m_iargc() RESULT (ic)
     INTEGER                                  :: ic
 
@@ -48,7 +49,8 @@ CONTAINS
 
 ! *****************************************************************************
 !> \brief Flush a given unit
-! *****************************************************************************
+!> \param lunit ...
+! **************************************************************************************************
   SUBROUTINE m_flush(lunit)
     INTEGER, INTENT(IN)                      :: lunit
 
@@ -59,7 +61,9 @@ CONTAINS
 ! *****************************************************************************
 !> \brief Returns if a process is running on the local machine
 !>        1 if yes and 0 if not
-! *****************************************************************************
+!> \param pid ...
+!> \return ...
+! **************************************************************************************************
   FUNCTION m_procrun(pid) RESULT (run_on)
     INTEGER, INTENT(IN)       ::   pid
     INTEGER                   ::   run_on
@@ -89,11 +93,12 @@ CONTAINS
 
 ! *****************************************************************************
 !> \brief Returns the total amount of memory [bytes] in use, if known, zero otherwise
-! *****************************************************************************
+!> \param mem ...
+! **************************************************************************************************
   SUBROUTINE m_memory(mem)
 
       INTEGER(KIND=int_8), OPTIONAL, INTENT(OUT)         :: mem
-      INTEGER(KIND=int_8)                      :: m1,m2,m3,mem_local
+      INTEGER(KIND=int_8)                      :: mem_local
 
       !
       ! __NO_STATM_ACCESS can be used to disable the stuff, if getpagesize
@@ -102,6 +107,7 @@ CONTAINS
 #if defined(__NO_STATM_ACCESS)
       mem_local=0
 #else
+      INTEGER(KIND=int_8)                      :: m1,m2,m3
       CHARACTER(LEN=80) :: DATA
       INTEGER :: iostat,i
 
@@ -154,6 +160,16 @@ CONTAINS
 ! *** memory we're likely to be able to allocate, but not necessarily in one chunk
 ! *** zero means not available
 ! *****************************************************************************
+! **************************************************************************************************
+!> \brief ...
+!> \param MemTotal ...
+!> \param MemFree ...
+!> \param Buffers ...
+!> \param Cached ...
+!> \param Slab ...
+!> \param SReclaimable ...
+!> \param MemLikelyFree ...
+! **************************************************************************************************
   SUBROUTINE m_memory_details(MemTotal,MemFree,Buffers,Cached,Slab,SReclaimable,MemLikelyFree)
 
      INTEGER(kind=int_8), OPTIONAL :: MemTotal,MemFree,Buffers,Cached,Slab,SReclaimable,MemLikelyFree
@@ -196,6 +212,11 @@ CONTAINS
 
 
   CONTAINS
+! **************************************************************************************************
+!> \brief ...
+!> \param field ...
+!> \return ...
+! **************************************************************************************************
         INTEGER(int_8) FUNCTION get_field_value_in_bytes(field)
            CHARACTER(LEN=*) :: field
            INTEGER :: start
@@ -216,7 +237,11 @@ CONTAINS
 
 
 ! *****************************************************************************
-! *****************************************************************************
+! **************************************************************************************************
+!> \brief ...
+!> \param source ...
+!> \param TARGET ...
+! **************************************************************************************************
   SUBROUTINE m_mov(source,TARGET)
 
     CHARACTER(LEN=*), INTENT(IN)             :: source, TARGET
@@ -260,7 +285,10 @@ CONTAINS
 
 
 ! *****************************************************************************
-! *****************************************************************************
+! **************************************************************************************************
+!> \brief ...
+!> \param hname ...
+! **************************************************************************************************
   SUBROUTINE m_hostnm(hname)
     CHARACTER(len=*), INTENT(OUT)            :: hname
 
@@ -287,7 +315,10 @@ CONTAINS
 
 
 ! *****************************************************************************
-! *****************************************************************************
+! **************************************************************************************************
+!> \brief ...
+!> \param curdir ...
+! **************************************************************************************************
   SUBROUTINE m_getcwd(curdir)
     CHARACTER(len=*), INTENT(OUT)            :: curdir
     TYPE(C_PTR)                              :: stat
@@ -314,7 +345,11 @@ CONTAINS
 
 
 ! *****************************************************************************
-! *****************************************************************************
+! **************************************************************************************************
+!> \brief ...
+!> \param dir ...
+!> \param ierror ...
+! **************************************************************************************************
   SUBROUTINE m_chdir(dir,ierror)
     CHARACTER(len=*), INTENT(IN)             :: dir
     INTEGER, INTENT(OUT)                     :: ierror
@@ -332,7 +367,10 @@ CONTAINS
 
 
 ! *****************************************************************************
-! *****************************************************************************
+! **************************************************************************************************
+!> \brief ...
+!> \param user ...
+! **************************************************************************************************
   SUBROUTINE m_getlog(user)
     CHARACTER(len=*), INTENT(OUT)            :: user
     INTEGER :: status
@@ -350,7 +388,10 @@ CONTAINS
 
 
 ! *****************************************************************************
-! *****************************************************************************
+! **************************************************************************************************
+!> \brief ...
+!> \param uid ...
+! **************************************************************************************************
   SUBROUTINE m_getuid(uid)
    INTEGER, INTENT(OUT)                     :: uid
 
@@ -366,7 +407,10 @@ CONTAINS
 
 
 ! *****************************************************************************
-! *****************************************************************************
+! **************************************************************************************************
+!> \brief ...
+!> \param pid ...
+! **************************************************************************************************
   SUBROUTINE m_getpid(pid)
    INTEGER, INTENT(OUT)                     :: pid
 
@@ -382,7 +426,11 @@ CONTAINS
 
 
 ! *****************************************************************************
-! *****************************************************************************
+! **************************************************************************************************
+!> \brief ...
+!> \param i ...
+!> \param arg ...
+! **************************************************************************************************
   SUBROUTINE m_getarg(i,arg)
     INTEGER, INTENT(IN)                      :: i
     CHARACTER(len=*), INTENT(OUT)            :: arg
