@@ -1,6 +1,6 @@
 !--------------------------------------------------------------------------------------------------!
 !   CP2K: A general program to perform molecular dynamics simulations                              !
-!   Copyright (C) 2000 - 2017  CP2K developers group                                               !
+!   Copyright (C) 2000 - 2018  CP2K developers group                                               !
 !--------------------------------------------------------------------------------------------------!
 
 #:include 'data/dbcsr.fypp'
@@ -10,7 +10,7 @@
 !>        type of the matrix.
 !> \param scalar ...
 !> \param matrix ...
-!> \retval encapsulated ...
+!> \return ...
 ! **************************************************************************************************
   FUNCTION make_conformant_scalar_${nametype1}$ (scalar, matrix) RESULT (encapsulated)
     ${type1}$, INTENT(IN)                      :: scalar
@@ -221,7 +221,7 @@
 !> \param trace ...
 ! **************************************************************************************************
   SUBROUTINE dbcsr_trace_a_${nametype1}$ (matrix_a, trace)
-    TYPE(dbcsr_type), INTENT(INOUT)          :: matrix_a
+    TYPE(dbcsr_type), INTENT(IN)              :: matrix_a
     ${type1}$, INTENT(OUT)                     :: trace
 
     TYPE(dbcsr_scalar_type)                  :: trace_scalar
@@ -240,7 +240,7 @@
 !> \param trace ...
 ! **************************************************************************************************
   SUBROUTINE dbcsr_trace_ab_${nametype1}$ (matrix_a, matrix_b, trace)
-    TYPE(dbcsr_type), INTENT(INOUT)          :: matrix_a, matrix_b
+    TYPE(dbcsr_type), INTENT(IN)              :: matrix_a, matrix_b
     ${type1}$, INTENT(INOUT)                   :: trace
 
     CALL dbcsr_trace_prv(matrix_a%prv, matrix_b%prv, trace)
@@ -406,7 +406,7 @@
 !> \param index_matrix ...
 !> \param lb ...
 !> \param ub ...
-!> \retval DATA ...
+!> \return ...
 ! **************************************************************************************************
   FUNCTION dbcsr_get_wms_data_${nametype1}$ (matrix, index_matrix, select_data_type, lb, ub) RESULT (DATA)
     TYPE(dbcsr_type), INTENT(IN)     :: matrix
@@ -425,7 +425,7 @@
 !> \param index_matrix ...
 !> \param lb ...
 !> \param ub ...
-!> \retval DATA ...
+!> \return ...
 ! **************************************************************************************************
   FUNCTION dbcsr_get_data_${nametype1}$ (matrix, select_data_type, lb, ub) RESULT (DATA)
     TYPE(dbcsr_type), INTENT(IN)     :: matrix
