@@ -22,10 +22,8 @@ class Kernel_dnt_tiny(object):
        output += "double *a_data, double *b_data, double *c_data){\n"
        output += "int shared_size = 0;\n"
        output += "//%s\n"%str(self.__dict__)
-       output += "int careful = (stack_size / %(grouping)d);\n"%self.__dict__
-       output += "int nruns = stack_size - careful * %(grouping)d;\n"%self.__dict__
-       output += "typedef void (*kernel)(const int*, int, int, double*, double*, double*);\n"
-       output += "static kernel kern_func = cusmm_dnt_tiny<%(m)d,%(n)d,%(k)d,%(split_thread)d,%(threads)d,%(grouping)d,%(minblocks)d>;\n"%self.__dict__
+       output += "typedef void (*kernel)(const int*, int, const double*, const double*, double*);\n"
+       output += "static kernel kern_func = cusmm_dnt_tiny<%(m)d,%(n)d,%(k)d,%(threads)d,%(grouping)d,%(minblocks)d>;\n"%self.__dict__
        output += "static bool configured = false;\n"
        output += "if(configured == false){\n"
        output += "  cudaError_t err = cudaFuncSetSharedMemConfig(kern_func, cudaSharedMemBankSizeEightByte);\n"
@@ -33,7 +31,7 @@ class Kernel_dnt_tiny(object):
        output += "  configured = true;\n"
        output += "}\n"
        output += "kern_func<<< ((stack_size + %(grouping)d - 1) / %(grouping)d), %(threads)d, shared_size, stream >>>\n"%self.__dict__
-       output += "(param_stack, careful, nruns, \n"
+       output += "(param_stack, stack_size, \n"
        output += "a_data, b_data, c_data);\n"
        output += "return(0);\n"
        output += "}\n"
@@ -42,23 +40,22 @@ class Kernel_dnt_tiny(object):
     @staticmethod
     def promising_parameters(m, n, k):
         params = []
-        grouping = 16
-        minblocks = 1
-        for threads in (64, 96, 128):
-            if(m*n > threads):
-                continue
-
-            buf_sz = 2*(m*k + k*n)
-            sizeof_int = 4; sizeof_double = 8
-            smem_tot = buf_sz*sizeof_double + 4*grouping*sizeof_int
-            if(smem_tot*minblocks > 64*1024):
-                continue # uses too much shared memory
-
-            params.append({'m':m, 'n':n, 'k':k,
-                           'threads':threads,
-                           'split_thread':32,
-                           'grouping':grouping,
-                           'minblocks':minblocks})
+        for minblocks in (7, 8, 14, 28):              # heuristic: kernel dependent optimum
+            for grouping in range(1, 33, 1):          # soft: divide stack work in chunks of grouping + the rest
+                for threads in (16, 32, 64):          # heuristic: not more than 2 warps per SM (sm_60)
+                    if (m * n > threads):
+                       continue                       # hard: not enough threads to cover result matrix
+                
+                    buf_sz = k * (m + n)
+                    sizeof_int = 4; sizeof_double = 8
+                    smem_tot = buf_sz * sizeof_double + 3 * grouping * sizeof_int
+                    if (smem_tot * minblocks > 48 * 1024): # hard: see cudaFuncSetCacheConfig() docu
+                       continue                       # hard: uses too much shared memory
+                
+                    params.append({'m':m, 'n':n, 'k':k,
+                                   'threads':threads,
+                                   'grouping':grouping,
+                                   'minblocks':minblocks})
         return(params)
 
 #EOF
