@@ -1,6 +1,6 @@
 !--------------------------------------------------------------------------------------------------!
 !   CP2K: A general program to perform molecular dynamics simulations                              !
-!   Copyright (C) 2000 - 2017  CP2K developers group                                               !
+!   Copyright (C) 2000 - 2018  CP2K developers group                                               !
 !--------------------------------------------------------------------------------------------------!
 
 #:include '../data/dbcsr.fypp'
@@ -12,7 +12,7 @@
 !>
 ! **************************************************************************************************
   SUBROUTINE dbcsr_trace_a_${nametype1}$(matrix_a, trace)
-    TYPE(dbcsr_type), INTENT(INOUT)           :: matrix_a
+    TYPE(dbcsr_type), INTENT(IN)               :: matrix_a
     ${type1}$, INTENT(INOUT)                   :: trace
 
     CHARACTER(len=*), PARAMETER :: routineN = 'dbcsr_trace_a_${nametype1}$', &
@@ -82,7 +82,7 @@
 !> \param[out] trace             the trace of the product of the matrices
 ! **************************************************************************************************
   SUBROUTINE dbcsr_trace_ab_${nametype1}$(matrix_a, matrix_b, trace)
-    TYPE(dbcsr_type), INTENT(INOUT)           :: matrix_a, matrix_b
+    TYPE(dbcsr_type), INTENT(IN)               :: matrix_a, matrix_b
     ${type1}$, INTENT(INOUT)                   :: trace
 
     CHARACTER(len=*), PARAMETER :: routineN = 'dbcsr_trace_ab_${nametype1}$', &
@@ -279,16 +279,15 @@
 !> \param method ...
 !> \param use_absolute ...
 !> \param filter_diag ...
-!> \param quick ...
 ! **************************************************************************************************
   SUBROUTINE dbcsr_filter_${nametype1}$ (matrix, eps, method, use_absolute, &
-       filter_diag, quick)
+       filter_diag)
     TYPE(dbcsr_type), INTENT(INOUT)           :: matrix
     ${type1}$, INTENT(IN)                      :: eps
     INTEGER, INTENT(IN), OPTIONAL            :: method
-    LOGICAL, INTENT(in), OPTIONAL            :: use_absolute, filter_diag, quick
+    LOGICAL, INTENT(in), OPTIONAL            :: use_absolute, filter_diag
     CALL dbcsr_filter_anytype (matrix, dbcsr_scalar(eps), method, &
-         use_absolute, filter_diag, quick)
+         use_absolute, filter_diag)
   END SUBROUTINE dbcsr_filter_${nametype1}$
 
 ! **************************************************************************************************
@@ -434,4 +433,142 @@
       CALL dbcsr_finalize(matrix)
       CALL timestop(handle)
    END SUBROUTINE dbcsr_add_on_diag_${nametype1}$
+
+
+! **************************************************************************************************
+!> \brief  Low level function to sum contiguous chunks of blocks of the matrices (matrix_a = matrix_a + beta*matrix_b)
+!> \param[inout] matrix_a       DBCSR matrix
+!> \param[in]    matrix_b       DBCSR matrix
+!> \param[in]    first_lb_a     ...
+!> \param[in]    first_lb_b     ...
+!> \param[in]    nze            ...
+!> \param[in]    do_scale       ...
+!> \param[in]    my_beta_scalar ...
+!> \param[in]    found          ...
+!> \param[in]    iw             ...
+! **************************************************************************************************
+   SUBROUTINE dbcsr_update_contiguous_blocks_${nametype1}$(matrix_a, matrix_b, first_lb_a, first_lb_b, nze, &
+                                                           do_scale, my_beta_scalar, found, iw)
+      
+      TYPE(dbcsr_type), INTENT(INOUT)                         :: matrix_a
+      TYPE(dbcsr_type), INTENT(IN)                            :: matrix_b
+      TYPE(dbcsr_scalar_type), INTENT(IN)                     :: my_beta_scalar
+      INTEGER, INTENT(IN)                                     :: first_lb_a, first_lb_b, nze, iw    
+      LOGICAL, INTENT(IN)                                     :: found, do_scale
+      
+      INTEGER                                                 :: ub_a, ub_b
+
+      ub_a = first_lb_a + nze - 1
+      ub_b = first_lb_b + nze - 1
+
+      IF (found) THEN
+         IF (do_scale) THEN
+           CALL ${nametype1}$axpy (nze, my_beta_scalar % ${base1}$_${prec1}$,  &
+                       matrix_b % data_area % d % ${base1}$_${prec1}$ (first_lb_b : ub_b), 1, &
+                       matrix_a % data_area % d % ${base1}$_${prec1}$ (first_lb_a : ub_a), 1)
+         ELSE
+           matrix_a % data_area % d %${base1}$_${prec1}$ (first_lb_a : ub_a) = &
+                matrix_a % data_area % d % ${base1}$_${prec1}$ (first_lb_a : ub_a) + &
+                matrix_b % data_area % d % ${base1}$_${prec1}$ (first_lb_b : ub_b)
+         ENDIF
+      ELSE
+         IF (do_scale) THEN
+           matrix_a % wms(iw) % data_area % d % ${base1}$_${prec1}$ (first_lb_a : ub_a) = &
+                my_beta_scalar % ${base1}$_${prec1}$ * &
+                matrix_b % data_area % d % ${base1}$_${prec1}$ (first_lb_b : ub_b)
+         ELSE
+           matrix_a % wms(iw) % data_area % d % ${base1}$_${prec1}$ (first_lb_a : ub_a) = &
+                matrix_b % data_area % d % ${base1}$_${prec1}$ (first_lb_b : ub_b)
+         ENDIF
+      ENDIF
+   END SUBROUTINE dbcsr_update_contiguous_blocks_${nametype1}$
+
+
+! **************************************************************************************************
+!> \brief Low level function to sum two matrices (matrix_a = matrix_a + beta*matrix_b
+!> \param[inout] matrix_a       DBCSR matrix
+!> \param[in]    matrix_b       DBCSR matrix
+!> \param[in]    iter           ...
+!> \param[in]    iw             ...
+!> \param[in]    do_scale       ...
+!> \param[in]    my_beta_scalar ...
+!> \param[inout] my_flop ...
+! **************************************************************************************************
+
+   SUBROUTINE dbcsr_add_anytype_${nametype1}$(matrix_a, matrix_b, iter, iw, do_scale, &
+                                              my_beta_scalar, my_flop)
+     TYPE(dbcsr_type), INTENT(INOUT)                         :: matrix_a
+     TYPE(dbcsr_type), INTENT(IN)                            :: matrix_b
+     TYPE(dbcsr_iterator), INTENT(INOUT)                     :: iter
+     INTEGER, INTENT(IN)                                     :: iw
+     LOGICAL, INTENT(IN)                                     :: do_scale
+     TYPE(dbcsr_scalar_type), INTENT(IN)                     :: my_beta_scalar
+     INTEGER(KIND=int_8), INTENT(INOUT)                      :: my_flop
+
+     INTEGER                                                 :: row, col, row_size, col_size, &
+                                                                nze, tot_nze, blk, & 
+                                                                lb_a, first_lb_a, lb_a_val, &
+                                                                lb_b, first_lb_b 
+     INTEGER, DIMENSION(2)                                   :: lb_row_blk
+     LOGICAL                                                 :: was_found, found, tr
+    
+     ! some start values
+     lb_row_blk(:) = 0
+     first_lb_a = matrix_a%wms(iw)%datasize + 1
+     first_lb_b = 0
+     tot_nze = 0
+     !
+     DO WHILE (dbcsr_iterator_blocks_left(iter))
+        CALL dbcsr_iterator_next_block(iter, row, col, blk, tr, lb_b, row_size, col_size)
+        nze = row_size*col_size
+        IF (nze .LE. 0) CYCLE
+        IF (lb_row_blk(1) .LT. row) THEN
+           lb_row_blk(1) = row
+           lb_row_blk(2) = matrix_a%row_p(row)+1
+        ENDIF
+        ! get b-block index
+        lb_b = ABS(lb_b)
+        CALL dbcsr_find_column(col, lb_row_blk(2), matrix_a%row_p(row+1), matrix_a%col_i, matrix_a%blk_p, blk, found)
+        lb_row_blk(2) = blk+1
+        ! get index of a-block lb_a whether found (from matrix_a) or not (from workspace array)
+        IF (found) THEN
+           my_flop = my_flop + nze * 2
+           lb_a = ABS (matrix_a%blk_p(blk))
+        ELSE
+           lb_a = matrix_a%wms(iw)%datasize + 1
+           lb_a_val = lb_a
+           IF (tr) lb_a_val = -lb_a
+           matrix_a%wms(iw)%lastblk = matrix_a%wms(iw)%lastblk+1
+           matrix_a%wms(iw)%row_i(matrix_a%wms(iw)%lastblk) = row
+           matrix_a%wms(iw)%col_i(matrix_a%wms(iw)%lastblk) = col
+           matrix_a%wms(iw)%blk_p(matrix_a%wms(iw)%lastblk) = lb_a_val
+           matrix_a%wms(iw)%datasize = matrix_a%wms(iw)%datasize + nze
+        ENDIF
+        ! at the first iteration we skip this and go directly to initialization after
+        IF (first_lb_b .NE. 0) THEN        
+           ! if found status is the same as before then probably we are in contiguous blocks
+           IF ((found .EQV. was_found) .AND. &
+               (first_lb_b + tot_nze .EQ. lb_b) .AND. &
+               (first_lb_a + tot_nze) .EQ. lb_a) THEN
+              tot_nze = tot_nze + nze
+              CYCLE
+          ENDIF
+          ! save block chunk
+          CALL dbcsr_update_contiguous_blocks_${nametype1}$(matrix_a, matrix_b, first_lb_a, first_lb_b, tot_nze, &
+                                                           do_scale, my_beta_scalar, was_found, iw)
+        ENDIF
+        !
+        first_lb_a = lb_a
+        first_lb_b = lb_b
+        tot_nze = nze
+        was_found = found        
+     ENDDO
+        
+     ! save the last block or chunk of blocks
+     IF (first_lb_b .NE. 0) THEN 
+        call dbcsr_update_contiguous_blocks_${nametype1}$(matrix_a, matrix_b, first_lb_a, first_lb_b, tot_nze, &
+                                                          do_scale, my_beta_scalar, was_found, iw)
+     ENDIF
+
+   END SUBROUTINE dbcsr_add_anytype_${nametype1}$
 #:endfor
