@@ -23,17 +23,17 @@ write(iunit,'(A,I0,A)')"  SUBROUTINE collocate_core_",lp,"(grid,coef_xyz,pol_x,p
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A,I0)')" integer, PARAMETER :: lp=",lp
-write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: sphere_bounds(*)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: map(-cmax:cmax,1:3)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
-write(iunit,'(A)')"    real(wp), INTENT(INOUT) :: grid(gridbounds(1,1):gridbounds(2,1), & "
+write(iunit,'(A)')"  INTEGER, PARAMETER :: dp = SELECTED_REAL_KIND ( 14, 200 )"
+write(iunit,'(A,I0)')" INTEGER, PARAMETER :: lp=",lp
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: cmax"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: gridbounds(2,3)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: sphere_bounds(*)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: map(-cmax:cmax,1:3)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(INOUT) :: grid(gridbounds(1,1):gridbounds(2,1), & "
 write(iunit,'(A)')"                                    gridbounds(1,2):gridbounds(2,2), &"
 write(iunit,'(A)')"                                    gridbounds(1,3):gridbounds(2,3))"
 write(iunit,'(A)')" CALL collocate_core_default(grid,coef_xyz,pol_x,pol_y,pol_z,&"
@@ -51,27 +51,27 @@ write(iunit,'(A,I0,A)')"  SUBROUTINE collocate_core_",lp,"(grid,coef_xyz,pol_x,p
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A,I0)')" integer, PARAMETER :: lp=",lp
-write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: sphere_bounds(*)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: map(-cmax:cmax,1:3)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
-write(iunit,'(A)')"    real(wp), INTENT(INOUT) :: grid(gridbounds(1,1):gridbounds(2,1), & "
+write(iunit,'(A)')"  INTEGER, PARAMETER :: dp = SELECTED_REAL_KIND ( 14, 200 )"
+write(iunit,'(A,I0)')" INTEGER, PARAMETER :: lp=",lp
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: cmax"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: gridbounds(2,3)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: sphere_bounds(*)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: map(-cmax:cmax,1:3)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(INOUT) :: grid(gridbounds(1,1):gridbounds(2,1), & "
 write(iunit,'(A)')"                                    gridbounds(1,2):gridbounds(2,2), &"
 write(iunit,'(A)')"                                    gridbounds(1,3):gridbounds(2,3))"
 write(iunit,'(A)')""
-write(iunit,'(A)')"    real(wp) ::  coef_xy(2,(lp+1)*(lp+2)/2)"
-write(iunit,'(A)')"    real(wp) ::  coef_x(4,0:lp)"
+write(iunit,'(A)')"    REAL(KIND=dp) ::  coef_xy(2,(lp+1)*(lp+2)/2)"
+write(iunit,'(A)')"    REAL(KIND=dp) ::  coef_x(4,0:lp)"
 write(iunit,'(A)')""
-write(iunit,'(A)')"    integer kg,k,jgmin,jg,j,j2,igmax,ig,i,kgmin,igmin,k2,i2,jg2,kg2"
-write(iunit,'(A)')"    integer sci,lxp,lyp,lzp"
-write(iunit,'(A)')"    real(wp) s01,s02,s03,s04,s(4)"
-write(iunit,'(A)')"    integer lxyz,lxy,lx"
+write(iunit,'(A)')"    INTEGER kg,k,jgmin,jg,j,j2,igmax,ig,i,kgmin,igmin,k2,i2,jg2,kg2"
+write(iunit,'(A)')"    INTEGER sci,lxp,lyp,lzp"
+write(iunit,'(A)')"    REAL(KIND=dp) s01,s02,s03,s04,s(4)"
+write(iunit,'(A)')"    INTEGER lxyz,lxy,lx"
 write(iunit,'(A)')""
 write(iunit,'(A)')"    sci=1"
 write(iunit,'(A)')""
@@ -114,7 +114,7 @@ CONTAINS
 SUBROUTINE write_kg_body()
   INTEGER :: lxp,lyp,lzp,lxy,lxyz  
 
-  write(iunit,'(A)')"       coef_xy=0.0_wp"
+  write(iunit,'(A)')"       coef_xy=0.0_dp"
   SELECT CASE (options%kg_loop_unroll_lxp)
   CASE (0)
     write(iunit,'(A)')"       lxyz = 0"
@@ -177,7 +177,7 @@ END SUBROUTINE
 SUBROUTINE write_jg_body()
   INTEGER :: lxp,lyp,lxy
 
-  write(iunit,'(A)')"          coef_x=0.0_wp"
+  write(iunit,'(A)')"          coef_x=0.0_dp"
   SELECT CASE (options%jg_loop_unroll_lxp)
   CASE (0)
     write(iunit,'(A)')"          lxy=0"
@@ -249,12 +249,12 @@ SUBROUTINE write_ig_loop()
 
   SELECT CASE(options%ig_loop_vector_notation)
   CASE(0)
-     write(iunit,'(A)')"             s01=0.0_wp"
-     write(iunit,'(A)')"             s02=0.0_wp"
-     write(iunit,'(A)')"             s03=0.0_wp"
-     write(iunit,'(A)')"             s04=0.0_wp"
+     write(iunit,'(A)')"             s01=0.0_dp"
+     write(iunit,'(A)')"             s02=0.0_dp"
+     write(iunit,'(A)')"             s03=0.0_dp"
+     write(iunit,'(A)')"             s04=0.0_dp"
   CASE(1)
-     write(iunit,'(A)')"             s(:)=0.0_wp"
+     write(iunit,'(A)')"             s(:)=0.0_dp"
   END SELECT
 
   SELECT CASE (options%ig_loop_unroll_lxp)
@@ -338,27 +338,27 @@ write(iunit,'(A)')"  SUBROUTINE collocate_core_default(grid,coef_xyz,pol_x,pol_y
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: lp"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: sphere_bounds(*)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: map(-cmax:cmax,1:3)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
-write(iunit,'(A)')"    real(wp), INTENT(INOUT) :: grid(gridbounds(1,1):gridbounds(2,1), & "
+write(iunit,'(A)')"  INTEGER, PARAMETER :: dp = SELECTED_REAL_KIND ( 14, 200 )"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: lp"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: cmax"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: gridbounds(2,3)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: sphere_bounds(*)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: map(-cmax:cmax,1:3)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(INOUT) :: grid(gridbounds(1,1):gridbounds(2,1), & "
 write(iunit,'(A)')"                                    gridbounds(1,2):gridbounds(2,2), &"
 write(iunit,'(A)')"                                    gridbounds(1,3):gridbounds(2,3))"
 write(iunit,'(A)')""
-write(iunit,'(A)')"    real(wp) ::  coef_xy(2,(lp+1)*(lp+2)/2)"
-write(iunit,'(A)')"    real(wp) ::  coef_x(4,0:lp)"
+write(iunit,'(A)')"    REAL(KIND=dp) ::  coef_xy(2,(lp+1)*(lp+2)/2)"
+write(iunit,'(A)')"    REAL(KIND=dp) ::  coef_x(4,0:lp)"
 write(iunit,'(A)')""
-write(iunit,'(A)')"    integer kg,k,jgmin,jg,j,j2,igmax,ig,i,kgmin,igmin,k2,i2,jg2,kg2"
-write(iunit,'(A)')"    integer sci,lxp,lyp,lzp"
-write(iunit,'(A)')"    real(wp) s01,s02,s03,s04,s(4)"
-write(iunit,'(A)')"    integer lxyz,lxy,lx"
+write(iunit,'(A)')"    INTEGER kg,k,jgmin,jg,j,j2,igmax,ig,i,kgmin,igmin,k2,i2,jg2,kg2"
+write(iunit,'(A)')"    INTEGER sci,lxp,lyp,lzp"
+write(iunit,'(A)')"    REAL(KIND=dp) s01,s02,s03,s04,s(4)"
+write(iunit,'(A)')"    INTEGER lxyz,lxy,lx"
 write(iunit,'(A)')""
 write(iunit,'(A)')"    sci=1"
 write(iunit,'(A)')""
@@ -369,7 +369,7 @@ write(iunit,'(A)')"       kg2=1-kg"
 write(iunit,'(A)')"       k=map(kg,3)"
 write(iunit,'(A)')"       k2=map(kg2,3)"
 write(iunit,'(A)')""
-write(iunit,'(A)')"       coef_xy=0.0_wp"
+write(iunit,'(A)')"       coef_xy=0.0_dp"
 write(iunit,'(A)')"       lxyz = 0"
 write(iunit,'(A)')"       DO lzp=0,lp"
 write(iunit,'(A)')"          lxy=0"
@@ -393,7 +393,7 @@ write(iunit,'(A)')"          igmin=sphere_bounds(sci)"
 write(iunit,'(A)')"          sci=sci+1"
 write(iunit,'(A)')"          igmax=1-igmin"
 write(iunit,'(A)')""
-write(iunit,'(A)')"          coef_x=0.0_wp"
+write(iunit,'(A)')"          coef_x=0.0_dp"
 write(iunit,'(A)')"          lxy=0"
 write(iunit,'(A)')"          DO lyp=0,lp"
 write(iunit,'(A)')"          DO lxp=0,lp-lyp"
@@ -407,10 +407,10 @@ write(iunit,'(A)')"          ENDDO"
 write(iunit,'(A)')""
 write(iunit,'(A)')"          DO ig=igmin,igmax"
 write(iunit,'(A)')"             i=map(ig,1)"
-write(iunit,'(A)')"             s01=0.0_wp"
-write(iunit,'(A)')"             s02=0.0_wp"
-write(iunit,'(A)')"             s03=0.0_wp"
-write(iunit,'(A)')"             s04=0.0_wp"
+write(iunit,'(A)')"             s01=0.0_dp"
+write(iunit,'(A)')"             s02=0.0_dp"
+write(iunit,'(A)')"             s03=0.0_dp"
+write(iunit,'(A)')"             s04=0.0_dp"
 write(iunit,'(A)')"             DO lxp=0,lp"
 write(iunit,'(A)')"                s01=s01+coef_x(1,lxp)*pol_x(lxp,ig)"
 write(iunit,'(A)')"                s02=s02+coef_x(2,lxp)*pol_x(lxp,ig)"
@@ -474,17 +474,17 @@ write(iunit,'(A,I0,A)')"  SUBROUTINE integrate_core_",lp,"(grid,coef_xyz,pol_x,p
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A,I0)')"    integer, PARAMETER      :: lp=",lp
-write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: sphere_bounds(*)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: map(-cmax:cmax,1:3)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(OUT)   :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: grid(gridbounds(1,1):gridbounds(2,1), & "
+write(iunit,'(A)')"  INTEGER, PARAMETER :: dp = SELECTED_REAL_KIND ( 14, 200 )"
+write(iunit,'(A,I0)')"    INTEGER, PARAMETER      :: lp=",lp
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: cmax"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: gridbounds(2,3)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: sphere_bounds(*)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: map(-cmax:cmax,1:3)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(OUT)   :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: grid(gridbounds(1,1):gridbounds(2,1), & "
 write(iunit,'(A)')"                                    gridbounds(1,2):gridbounds(2,2), &"
 write(iunit,'(A)')"                                    gridbounds(1,3):gridbounds(2,3))"
 write(iunit,'(A)')" CALL integrate_core_default(grid,coef_xyz,pol_x,pol_y, &"
@@ -503,31 +503,31 @@ write(iunit,'(A,I0,A)')"  SUBROUTINE integrate_core_",lp,"(grid,coef_xyz,pol_x,p
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A,I0)')"    integer, PARAMETER      :: lp=",lp
-write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: sphere_bounds(*)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: map(-cmax:cmax,1:3)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(OUT)   :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: grid(gridbounds(1,1):gridbounds(2,1), & "
+write(iunit,'(A)')"  INTEGER, PARAMETER :: dp = SELECTED_REAL_KIND ( 14, 200 )"
+write(iunit,'(A,I0)')"    INTEGER, PARAMETER      :: lp=",lp
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: cmax"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: gridbounds(2,3)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: sphere_bounds(*)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: map(-cmax:cmax,1:3)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(OUT)   :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: grid(gridbounds(1,1):gridbounds(2,1), & "
 write(iunit,'(A)')"                                    gridbounds(1,2):gridbounds(2,2), &"
 write(iunit,'(A)')"                                    gridbounds(1,3):gridbounds(2,3))"
 write(iunit,'(A)')""
-write(iunit,'(A)')"    real(wp) ::  coef_xy(2,((lp+1)*(lp+2))/2)"
-write(iunit,'(A)')"    real(wp) ::  coef_x(4,0:lp)"
+write(iunit,'(A)')"    REAL(KIND=dp) ::  coef_xy(2,((lp+1)*(lp+2))/2)"
+write(iunit,'(A)')"    REAL(KIND=dp) ::  coef_x(4,0:lp)"
 write(iunit,'(A)')""
-write(iunit,'(A)')"    integer kg,k,jgmin,jg,j,j2,igmax,ig,i,kgmin,igmin,k2,i2,jg2,kg2"
-write(iunit,'(A)')"    integer sci,lxp,lyp,lzp"
-write(iunit,'(A)')"    real(wp) s01,s02,s03,s04,s(4)"
-write(iunit,'(A)')"    integer lxyz,lxy,lx"
+write(iunit,'(A)')"    INTEGER kg,k,jgmin,jg,j,j2,igmax,ig,i,kgmin,igmin,k2,i2,jg2,kg2"
+write(iunit,'(A)')"    INTEGER sci,lxp,lyp,lzp"
+write(iunit,'(A)')"    REAL(KIND=dp) s01,s02,s03,s04,s(4)"
+write(iunit,'(A)')"    INTEGER lxyz,lxy,lx"
 write(iunit,'(A)')""
 write(iunit,'(A)')"    sci=1"
 write(iunit,'(A)')""
-write(iunit,'(A)')"    coef_xyz=0.0_wp"
+write(iunit,'(A)')"    coef_xyz=0.0_dp"
 write(iunit,'(A)')""
 write(iunit,'(A)')"    kgmin=sphere_bounds(sci)"
 write(iunit,'(A)')"    sci=sci+1"
@@ -536,7 +536,7 @@ write(iunit,'(A)')"       kg2=1-kg"
 write(iunit,'(A)')"       k=map(kg,3)"
 write(iunit,'(A)')"       k2=map(kg2,3)"
 write(iunit,'(A)')""
-write(iunit,'(A)')"       coef_xy=0.0_wp"
+write(iunit,'(A)')"       coef_xy=0.0_dp"
 write(iunit,'(A)')""
 write(iunit,'(A)')"       jgmin=sphere_bounds(sci)"
 write(iunit,'(A)')"       sci=sci+1"
@@ -548,7 +548,7 @@ write(iunit,'(A)')"          igmin=sphere_bounds(sci)"
 write(iunit,'(A)')"          sci=sci+1"
 write(iunit,'(A)')"          igmax=1-igmin"
 write(iunit,'(A)')""
-write(iunit,'(A)')"          coef_x=0.0_wp"
+write(iunit,'(A)')"          coef_x=0.0_dp"
 
 CALL write_ig_loop()
 
@@ -761,31 +761,31 @@ write(iunit,'(A)')"  SUBROUTINE integrate_core_default(grid,coef_xyz,pol_x,pol_y
 write(iunit,'(A)')""
 write(iunit,'(A)')"    IMPLICIT NONE"
 write(iunit,'(A)')""
-write(iunit,'(A)')"  INTEGER, PARAMETER :: wp = SELECTED_REAL_KIND ( 14, 200 )"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: lp"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: cmax"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: gridbounds(2,3)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: sphere_bounds(*)"
-write(iunit,'(A)')"    integer, INTENT(IN)     :: map(-cmax:cmax,1:3)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
-write(iunit,'(A)')"    real(wp), INTENT(OUT)   :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
-write(iunit,'(A)')"    real(wp), INTENT(IN)    :: grid(gridbounds(1,1):gridbounds(2,1), & "
+write(iunit,'(A)')"  INTEGER, PARAMETER :: dp = SELECTED_REAL_KIND ( 14, 200 )"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: lp"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: cmax"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: gridbounds(2,3)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: sphere_bounds(*)"
+write(iunit,'(A)')"    INTEGER, INTENT(IN)     :: map(-cmax:cmax,1:3)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_x(0:lp,-cmax:cmax)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_y(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: pol_z(1:2,0:lp,-cmax:0)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(OUT)   :: coef_xyz(((lp+1)*(lp+2)*(lp+3))/6)"
+write(iunit,'(A)')"    REAL(KIND=dp), INTENT(IN)    :: grid(gridbounds(1,1):gridbounds(2,1), & "
 write(iunit,'(A)')"                                    gridbounds(1,2):gridbounds(2,2), &"
 write(iunit,'(A)')"                                    gridbounds(1,3):gridbounds(2,3))"
 write(iunit,'(A)')""
-write(iunit,'(A)')"    real(wp) ::  coef_xy(2,((lp+1)*(lp+2))/2)"
-write(iunit,'(A)')"    real(wp) ::  coef_x(4,0:lp)"
+write(iunit,'(A)')"    REAL(KIND=dp) ::  coef_xy(2,((lp+1)*(lp+2))/2)"
+write(iunit,'(A)')"    REAL(KIND=dp) ::  coef_x(4,0:lp)"
 write(iunit,'(A)')""
-write(iunit,'(A)')"    integer kg,k,jgmin,jg,j,j2,igmax,ig,i,kgmin,igmin,k2,i2,jg2,kg2"
-write(iunit,'(A)')"    integer sci,lxp,lyp,lzp"
-write(iunit,'(A)')"    real(wp) s01,s02,s03,s04,s(4)"
-write(iunit,'(A)')"    integer lxyz,lxy,lx"
+write(iunit,'(A)')"    INTEGER kg,k,jgmin,jg,j,j2,igmax,ig,i,kgmin,igmin,k2,i2,jg2,kg2"
+write(iunit,'(A)')"    INTEGER sci,lxp,lyp,lzp"
+write(iunit,'(A)')"    REAL(KIND=dp) s01,s02,s03,s04,s(4)"
+write(iunit,'(A)')"    INTEGER lxyz,lxy,lx"
 write(iunit,'(A)')""
 write(iunit,'(A)')"    sci=1"
 write(iunit,'(A)')""
-write(iunit,'(A)')"    coef_xyz=0.0_wp"
+write(iunit,'(A)')"    coef_xyz=0.0_dp"
 write(iunit,'(A)')""
 write(iunit,'(A)')"    kgmin=sphere_bounds(sci)"
 write(iunit,'(A)')"    sci=sci+1"
@@ -794,7 +794,7 @@ write(iunit,'(A)')"       kg2=1-kg"
 write(iunit,'(A)')"       k=map(kg,3)"
 write(iunit,'(A)')"       k2=map(kg2,3)"
 write(iunit,'(A)')""
-write(iunit,'(A)')"       coef_xy=0.0_wp"
+write(iunit,'(A)')"       coef_xy=0.0_dp"
 write(iunit,'(A)')""
 write(iunit,'(A)')"       jgmin=sphere_bounds(sci)"
 write(iunit,'(A)')"       sci=sci+1"
@@ -806,7 +806,7 @@ write(iunit,'(A)')"          igmin=sphere_bounds(sci)"
 write(iunit,'(A)')"          sci=sci+1"
 write(iunit,'(A)')"          igmax=1-igmin"
 write(iunit,'(A)')""
-write(iunit,'(A)')"          coef_x=0.0_wp"
+write(iunit,'(A)')"          coef_x=0.0_dp"
 write(iunit,'(A)')""
 write(iunit,'(A)')"          DO ig=igmin,igmax"
 write(iunit,'(A)')"             i=map(ig,1)"
