@@ -1,6 +1,6 @@
 PROGRAM dumpdcd
 
-! Copyright (C) 2012 - 2015  Matthias Krack (MK)
+! Copyright (C) 2012 - 2016  Matthias Krack (MK)
 !
 ! Version: 3.0
 ! Author:  Matthias Krack (MK)
@@ -15,6 +15,8 @@ PROGRAM dumpdcd
 !          - VEL to CORD (-vel2cord flag) hack added (25.06.2012,MK)
 !          - Added -displacement (-disp) flag (26.06.2012,MK)
 !          - Dump the atomic displacements (CORD file) or temperatures (VEL file as x-coordinates of a DCD file (28.06.2012,MK)
+!          - FRC to CORD (-frc2cord flag) hack added (28.01.2016,MK)
+!          - Option -eformat added (15.02.2016,MK)
 !
 ! Note: For -ekin a XYZ file is required to obtain the atomic labels.
 !       The -info and the -debug flags provide a more detailed output which is especially handy for tracing problems.
@@ -53,6 +55,7 @@ PROGRAM dumpdcd
   ! Variables
   CHARACTER(LEN=4)                                   :: id_dcd
   CHARACTER(LEN=10)                                  :: unit_string
+  CHARACTER(LEN=17)                                  :: fmt_string
   CHARACTER(LEN=default_string_length)               :: arg,dcd_file_name,message,out_file_name,output_format,&
                                                         remark_xyz,string,xyz_file_name
   CHARACTER(LEN=5), DIMENSION(:), ALLOCATABLE        :: atomic_label
@@ -61,12 +64,12 @@ PROGRAM dumpdcd
                                                         iatom,iskip,istat,istep,last_frame,narg,&
                                                         natom_dcd,natom_xyz,ndcd_file,nframe,&
                                                         nframe_read,nremark,stride
-  LOGICAL                                            :: apply_pbc,debug,dump_frame,ekin,eo,have_atomic_labels,&
+  LOGICAL                                            :: apply_pbc,debug,dump_frame,eformat,ekin,eo,have_atomic_labels,&
                                                         info,opened,output_format_dcd,output_format_xmol,&
                                                         pbc0,print_atomic_displacements,print_scaled_coordinates,&
                                                         print_scaled_pbc_coordinates,trace_atoms,vel2cord
   REAL(KIND=sp)                                      :: dt
-  REAL(KIND=dp)                                      :: a,alpha,b,beta,c,eps_out_of_box,gamma,tavg,tavg_frame,x
+  REAL(KIND=dp)                                      :: a,alpha,b,beta,c,eps_out_of_box,gamma,tavg,tavg_frame
   INTEGER, DIMENSION(16)                             :: idum
   REAL(KIND=dp), DIMENSION(3)                        :: rdum
   REAL(KIND=dp), DIMENSION(:), ALLOCATABLE           :: atomic_displacement,atomic_mass,atomic_temperature
@@ -78,6 +81,7 @@ PROGRAM dumpdcd
   pbc0 = .FALSE.
   debug = .FALSE.
   dump_frame = .TRUE.
+  eformat = .FALSE.
   ekin = .FALSE.
   eo = .FALSE.
   info = .FALSE.
@@ -106,6 +110,7 @@ PROGRAM dumpdcd
   output_format_xmol = .FALSE.
   remark_dcd(:) = ""
   remark_xyz = ""
+  fmt_string = ""
   dt = 0.0_sp
   a = 0.0_dp
   b = 0.0_dp
@@ -140,6 +145,9 @@ PROGRAM dumpdcd
     CASE ("-displacements","-disp")
       print_atomic_displacements = .TRUE.
       CYCLE dcd_file_loop
+    CASE ("-eformat")
+      eformat = .TRUE.
+      CYCLE dcd_file_loop
     CASE ("-ekin")
       ekin = .TRUE.
       CYCLE dcd_file_loop
@@ -227,7 +235,7 @@ PROGRAM dumpdcd
       trace_atoms = .TRUE.
       CYCLE dcd_file_loop
 108   CALL abort_program(routine_name,"Invalid threshold value for -trace_atoms flag specified")
-    CASE ("-vel2cord","-v2c")
+    CASE ("-vel2cord","-v2c","-frc2cord","-f2c")
       vel2cord = .TRUE.
       CYCLE dcd_file_loop
     CASE ("-xyz","xyz_file")
@@ -278,6 +286,13 @@ PROGRAM dumpdcd
       CALL abort_program(routine_name,"The -spc flag requires the specification of a -pbc flag")
     END IF
 
+    ! Use optionally an ES format
+    IF (eformat) THEN
+      fmt_string = "(A5,3(1X,ES14.6))"
+    ELSE
+      fmt_string = "(A5,3(1X, F14.6))"
+    END IF
+
     ! Open output units as requested
     IF (output_format_dcd) THEN
       ! Set default output file name if no file name was specified
@@ -437,7 +452,7 @@ PROGRAM dumpdcd
       CALL abort_program(routine_name,"pbc flags require that unit cell information is available")
     END IF
 
-    IF (TRIM(ADJUSTL(id_dcd)) == "VEL") THEN
+    IF ((TRIM(ADJUSTL(id_dcd)) == "FRC").OR.(TRIM(ADJUSTL(id_dcd)) == "VEL")) THEN
       unit_string = "[a.u.]"
       IF (apply_pbc) CALL abort_program(routine_name,"pbc flags require a DCD file with COoRDinates")
     ELSE IF (TRIM(ADJUSTL(id_dcd)) == "CORD") THEN
@@ -675,9 +690,10 @@ PROGRAM dumpdcd
               END IF
             ELSE
               IF (output_format_xmol) THEN
-                WRITE (UNIT=output_unit,FMT="(T2,I0,/,A)") natom_dcd,TRIM(remark_xyz)
+                WRITE (UNIT=output_unit,FMT="(T2,I0,/,A,2(I0,A))")&
+                  natom_dcd,"Frame: ",nframe_read + 1,", Step: ",nframe,", "//TRIM(remark_xyz)
                 DO iatom=1,natom_dcd
-                  WRITE (UNIT=output_unit,FMT="(A5,3(1X,F14.6))") ADJUSTL(atomic_label(iatom)),r(iatom,1:3)
+                  WRITE (UNIT=output_unit,FMT=fmt_string) ADJUSTL(atomic_label(iatom)),r(iatom,1:3)
                 END DO
               ELSE
                 IF (info) THEN
@@ -686,15 +702,15 @@ PROGRAM dumpdcd
                 END IF
                 IF (print_scaled_coordinates) THEN
                   DO iatom=1,natom_dcd
-                    WRITE (UNIT=output_unit,FMT="(A5,3(1X,F14.6))") ADJUSTL(atomic_label(iatom)),s(iatom,1:3)
+                    WRITE (UNIT=output_unit,FMT=fmt_string) ADJUSTL(atomic_label(iatom)),s(iatom,1:3)
                   END DO
                 ELSE IF (print_scaled_pbc_coordinates) THEN
                   DO iatom=1,natom_dcd
-                    WRITE (UNIT=output_unit,FMT="(A5,3(1X,F14.6))") ADJUSTL(atomic_label(iatom)),s_pbc(iatom,1:3)
+                    WRITE (UNIT=output_unit,FMT=fmt_string) ADJUSTL(atomic_label(iatom)),s_pbc(iatom,1:3)
                   END DO
                 ELSE
                   DO iatom=1,natom_dcd
-                    WRITE (UNIT=output_unit,FMT="(A5,3(1X,F14.6))") ADJUSTL(atomic_label(iatom)),r(iatom,1:3)
+                    WRITE (UNIT=output_unit,FMT=fmt_string) ADJUSTL(atomic_label(iatom)),r(iatom,1:3)
                   END DO
                 END IF
               END IF
@@ -1066,6 +1082,7 @@ CONTAINS
      "",&
      " -debug, -d                     : Print debug information",&
      " -ekin                          : Dump just the ""temperature"" of each atom",&
+     " -eformat                       : Print coordinates in scientific format",&
      " -eo                            : Write standard output and standard error to the same logical unit",&
      " -first_frame, -ff <int>        : Number of the first frame which is dumped",&
      " -help, -h                      : Print this information",&
@@ -1107,6 +1124,7 @@ CONTAINS
      " dumpdcd -o new.dcd -of dcd -pbc -trace_atoms 0.02 old.dcd (all atoms more than 2% out of the box are listed)",&
      " dumpdcd -o new.dcd -e out_of_box.log -of dcd -pbc -trace_atoms 0.1 old.dcd (atoms more than 10% out of the box are listed)",&
      " dumpdcd -o new.dcd -of dcd -vel2cord old.dcd (dump old.dcd as new.dcd and change only the DCD id string from VEL to CORD)",&
+     " dumpdcd -o new.dcd -of dcd -frc2cord old.dcd (dump old.dcd as new.dcd and change only the DCD id string from FRC to CORD)",&
      " dumpdcd -i -disp UO2-2x2x2-pos-1.dcd (dump the displacements of all atoms w.r.t. their positions in the first frame)",&
      " dumpdcd -i -of dcd -disp UO2-2x2x2-pos-1.dcd (dump the atomic displacements as x-coordinates of a DCD CORD file)",&
      " dumpdcd -i -of dcd -ekin -v2c -xyz UO2-2x2x2.xyz UO2-2x2x2-vel-1.dcd (dump the atomic temperatures as x-coordinates of a ",&
