@@ -1,23 +1,23 @@
 # default package versions
-binutils_ver=${binutils_ver:-2.28}
-cmake_ver=${cmake_ver:-3.1.1}
+binutils_ver=${binutils_ver:-2.30}
+cmake_ver=${cmake_ver:-3.11.2}
 elpa_ver=${elpa_ver:-2017.05.002}
-fftw_ver=${fftw_ver:-3.3.6-pl1}
-gcc_ver=${gcc_ver:-6.3.0}
+fftw_ver=${fftw_ver:-3.3.7}
+gcc_ver=${gcc_ver:-7.3.0}
 lcov_ver=${lcov_ver:-1.13}
 libint_ver=${libint_ver:-1.1.6}
-libxc_ver=${libxc_ver:-3.0.0}
-mpich_ver=${mpich_ver:-3.2}
+libxc_ver=${libxc_ver:-4.0.3}
+mpich_ver=${mpich_ver:-3.2.1}
 openblas_ver=${openblas_ver:-0.2.20}
-openmpi_ver=${openmpi_ver:-2.0.2}
+openmpi_ver=${openmpi_ver:-3.1.0}
 parmetis_ver=${parmetis_ver:-4.0.3}
-pexsi_ver=${pexsi_ver:-0.10.1}
+pexsi_ver=${pexsi_ver:-0.10.2}
 plumed_ver=${plumed_ver:-2.2b}
 quip_ver=${quip_ver:-cc83ceea5776c40fcb5ab224a25ab04d62175449}
-reflapack_ver=${reflapack_ver:-3.5.0}
+reflapack_ver=${reflapack_ver:-3.8.0}
 scalapack_ver=${scalapack_ver:-2.0.2}
 scotch_ver=${scotch_ver:-6.0.0}
 superlu_ver=${superlu_ver:-5.1.2}
 valgrind_ver=${valgrind_ver:-3.12.0}
-libxsmm_ver=${libxsmm_ver:-1.7.1}
-make_ver=${make_ver:-4.1}
+libxsmm_ver=${libxsmm_ver:-1.9.0}
+make_ver=${make_ver:-4.2}
